#
# spec file for package kf6-knotifications
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.8.0

%define rname knotifications

%bcond_without kde_python_bindings
%if %{with kde_python_bindings}
%if 0%{suse_version} > 1500
%define pythons %{primary_python}
%else
%{?sle15_python_module_pythons}
%endif
%define mypython %pythons
%define __mypython %{expand:%%__%{mypython}}
%define mypython_sitearch %{expand:%%%{mypython}_sitearch}
%endif

# Full KF6 version (e.g. 6.15.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without released
Name:           kf6-knotifications
Version:        6.15.0
Release:        1.1
Summary:        KDE Desktop notifications
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Config) >= %{_kf6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libcanberra)
# SECTION bindings
%if %{with kde_python_bindings}
BuildRequires:  %{mypython}-build
BuildRequires:  %{mypython}-devel >= 3.9
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  cmake(Shiboken6)
BuildRequires:  cmake(PySide6)
%endif
# /SECTION

%description
KNotification is used to notify the user of an event. It covers feedback and
persistent events.

%package imports
Summary:        KDE Desktop notifications - QML files

%description imports
KNotification is used to notify the user of an event. It covers feedback and
persistent events.
This package contains files that allow using knotification in QtQuick based
applications.

%package -n libKF6Notifications6
Summary:        KDE Desktop notifications
Requires:       kf6-knotifications >= %{version}

%description -n libKF6Notifications6
KNotification is used to notify the user of an event. It covers feedback and
persistent events.

%package devel
Summary:        KDE Desktop notifications: Build Environment
Requires:       libKF6Notifications6 = %{version}
Requires:       cmake(Qt6DBus) >= %{qt6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
KNotification is used to notify the user of an event. It covers feedback and
persistent events. Development files.

%if %{with kde_python_bindings}
%package -n python3-kf6-knotifications
Summary:        Python interface for kf6-knotifications

%description -n python3-kf6-knotifications
This package provides a python interface for kf6-knotifications.
%endif

%lang_package -n libKF6Notifications6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 \
%if %{with kde_python_bindings}
  -DPython_EXECUTABLE:STRING=%{__mypython}
%endif
%{nil}

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang knotifications6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6Notifications6

%files -n libKF6Notifications6-lang -f knotifications6.lang

%files
%{_kf6_debugdir}/knotifications.categories
%{_kf6_debugdir}/knotifications.renamecategories

%files imports
%{_kf6_qmldir}/org/kde/notification/

%files -n libKF6Notifications6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6Notifications.so.*

%files devel
%{_kf6_cmakedir}/KF6Notifications/
%{_kf6_includedir}/KNotifications/
%{_kf6_libdir}/libKF6Notifications.so

%if %{with kde_python_bindings}
%files -n python3-kf6-knotifications
%{mypython_sitearch}/*.so
%endif

%changelog
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * Update dependency version to 6.15.0
  * Disable python bindings for Haiku also
  * Build Python bindings unless explicitly disabled
  * Add tags file to documentation
  * Fix qhp file for QML module
  * Add landing page for QDoc
  * Port API documentation to QDoc syntax
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Update version to 6.14.0
  * NotifyByPopup: Drop temporary image to PNG conversion
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * KNotification: Update notification when action label changes
  * It compiles fine without qt6.9 deprecated methods
  * It compiles fine without kf6.12 deprecated methods
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Add xml/yaml linting
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Add xml/yaml linting
  * Enable Python bindings on FreeBSD
  * CI: Add linux-qt6-next build
  * Lower Python requirement to 3.9
  * Remove unused string from Android manifest
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * NotifyByAndroid: Set CONTEXT_NOT_EXPORTED
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Add Python bindings
  * It compiles fine without deprecated methods
  * ci: add Alpine/musl job
  * Disable Canberra check for Haiku also
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * typo--
  * Add namespace for Android as required by newer gradle
  * Add CI for static builds on Linux
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Fix Android notification permission check
  * Ensure notification permission request callback is run on the right thread
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Don't set desktop file name for XDG activation token
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * allow to build on oses without dbus and any other backend
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * fix missing HAVE_DBUS usages
  * support USE_DBUS option to enable/disable dbus use
  * Adapt Android default notifications and documentations to KF6 search path
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Don't include quiet package in feature_summary
  * notifybysnore: correct action buttons (kde#486911)
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Enforce passing tests on Windows
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Port QML module to declarative type registration
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-knotifications
